# ------------------------------------------------------------ Imports ----------------------------------------------------------- #

# System
from enum import Enum

# -------------------------------------------------------------------------------------------------------------------------------- #



# ------------------------------------------------------- enum: AmazonError ------------------------------------------------------ #

class AmazonError(Enum):
    NoResponse      = 'NoResponse'
    Captcha         = 'Captcha'
    AutomatedAccess = 'AutomatedAccess'


# -------------------------------------------------------------------------------------------------------------------------------- #